@@ -55,34 +55,7 @@ classicthemerestorerjso.ctr = {
 	// disable and hide items not usable on third party themes
 	if (!this.fxdefaulttheme) {
 		document.getElementById('ctraddon_pw_tabmenulist').disabled = true;
-		document.getElementById('ctraddon_abhigher').disabled = true;
-		document.getElementById('ctraddon_pw_smallnavbut').disabled = true;
-		document.getElementById('ctraddon_pw_iconsbig').disabled = true;
-		document.getElementById('ctraddon_pw_altmenubar').disabled = true;
-		document.getElementById('ctraddon_pw_menubarnofog').disabled = true;
-		document.getElementById('ctraddon_pw_tabmokcolor').disabled = true;
-		document.getElementById('ctraddon_pw_tabmokcolor2').disabled = true;
-		document.getElementById('ctraddon_pw_tabmokcolor4').disabled = true;
-		document.getElementById('ctraddon_pw_panelmenucolor').disabled = true;
-		document.getElementById('ctraddon_pw_nobookbarbg').disabled = true;
-		document.getElementById('ctraddon_pw_nonavborder').disabled = true;
-		document.getElementById('ctraddon_pw_nonavtbborder').disabled = true;
-		document.getElementById('ctraddon_pw_alttabstb').disabled = true;
-		document.getElementById('ctraddon_pw_alttabstb2').disabled = true;
-		document.getElementById('ctraddon_pw_ib_graycolor').disabled = true;
-		document.getElementById('ctraddon_pw_verifiedcolors').disabled = true;
 		document.getElementById('ctraddon_pw_colors_ntab_t').disabled = true;
-		document.getElementById('ctraddon_pw_notabfog').disabled = true;
-		document.getElementById('ctraddon_pw_notabbg').disabled = true;
-		document.getElementById('ctraddon_pw_noaddonbarbg').disabled = true;
-		document.getElementById('ctraddon_pw_noconicons').disabled = true;
-		document.getElementById('ctraddon_pw_closeonleft').disabled = true;
-		document.getElementById('ctraddon_pw_nbcompact').disabled = true;
-		document.getElementById('ctraddon_pw_tabc_act_tb').disabled = true;
-		document.getElementById('ctraddon_pw_aerocolors').disabled = true;
-		document.getElementById('ctraddon_pw_tbsep_winc').disabled = true;
-		document.getElementById('ctraddon_pw_alt_addonsm').disabled = true;
-		document.getElementById('ctraddon_pw_tttitlebar').disabled = true;
 
 		document.getElementById('ctraddon_abhigher').style.visibility = 'collapse';
 		document.getElementById('ctraddon_pw_smallnavbut').style.visibility = 'collapse';
@@ -93,7 +66,6 @@ classicthemerestorerjso.ctr = {
 		document.getElementById('ctraddon_pw_ccol_act_cp2').style.visibility = 'collapse';
 		document.getElementById('ctraddon_pw_ccol_act_b1').style.visibility = 'collapse';
 		document.getElementById('ctraddon_pw_ccol_act_b2').style.visibility = 'collapse';
-
 		document.getElementById('ctraddon_pw_altmenubar').style.visibility = 'collapse';
 		document.getElementById('ctraddon_pw_menubarnofog').style.visibility = 'collapse';
 		document.getElementById('ctraddon_pw_tabmokcolor').style.visibility = 'collapse';
@@ -120,27 +92,34 @@ classicthemerestorerjso.ctr = {
 		document.getElementById('ctraddon_pw_tabc_act_tb').style.visibility = 'collapse';
 		document.getElementById('ctraddon_pw_aerocolors').style.visibility = 'collapse';
 		document.getElementById('ctraddon_pw_tbsep_winc').style.visibility = 'collapse';
-		document.getElementById('ctraddon_pw_alt_addonsm').style.visibility = 'collapse';
 		document.getElementById('ctraddon_pw_transpttbw10').style.visibility = 'collapse';
 		document.getElementById('ctraddon_pw_transpttbew10').style.visibility = 'collapse';
 		document.getElementById('ctraddon_pw_locsearchbw10').style.visibility = 'collapse';
 		document.getElementById('ctraddon_pw_bookmarksbargroup2').style.visibility = 'collapse';
 		document.getElementById('ctraddon_pw_tabstoolbargroup').style.visibility = 'collapse';
 		document.getElementById('ctraddon_pw_menubargroup2').style.visibility = 'collapse';
-		document.getElementById('ctraddon_pw_hightabpososx').style.visibility = 'collapse';
-		document.getElementById('ctraddon_altoptions_list').style.visibility = 'collapse';
+		document.getElementById('ctraddon_pw_hightabpososx').style.visibility = 'collapse';	
 		document.getElementById('ctraddon_pw_tttitlebar').style.visibility = 'collapse';
 		document.getElementById('ctraddon_pw_am_compact').style.visibility = 'collapse';
 		document.getElementById('ctraddon_pw_am_compact2').style.visibility = 'collapse';
 		document.getElementById('ctraddon_pw_ib_nohovcolor').style.visibility = 'collapse';
 		document.getElementById('ctraddon_pw_altreaderico').style.visibility = 'collapse';
+		document.getElementById('ctraddon_pw_alt_addonsm').style.visibility = 'collapse';
+		document.getElementById('ctraddon_altoptions_list').style.visibility = 'collapse';
+		
 	} else {
 		document.getElementById('ctraddon_pw_themes_note').style.visibility = 'collapse';
 		document.getElementById('ctraddon_pw_special_font').style.visibility = 'collapse';
 		document.getElementById('ctraddon_pw_tabforminfo').style.visibility = 'collapse';
-		document.getElementById('ctraddon_altoptions_list2').style.visibility = 'collapse';
 		document.getElementById('ctraddon_pw_dblclnewtabdes').style.visibility = 'collapse';
+		document.getElementById('ctraddon_altoptions_list2').style.visibility = 'collapse';
 	};
+	
+	if(Services.prefs.getBranch("lightweightThemes.").getCharPref('selectedThemeID')=='firefox-devedition@mozilla.org') {
+	  document.getElementById('ctraddon_altoptions_list').style.visibility = 'visible';
+	  document.getElementById('ctraddon_pw_alt_addonsm').style.visibility = 'visible';
+	  document.getElementById('ctraddon_altoptions_list2').style.visibility = 'collapse';
+	}
 
 	// ColorfulTabs info label
 	document.getElementById('ctraddon_coltabsinfo').style.visibility = 'collapse';
@@ -407,6 +386,7 @@ classicthemerestorerjso.ctr = {
 	  document.getElementById('ctraddon_pw_cresultshbox').style.visibility = 'collapse';
 	  document.getElementById('ctraddon_pw_aboutpages').style.visibility = 'collapse';
 	  document.getElementById('ctraddon_pw_ctrltabprev').style.visibility = 'collapse';
+	  document.getElementById('ctraddon_pw_autocompl_not').style.visibility = 'collapse';
 	}
 
 	if (this.appversion >= 48) {
@@ -503,23 +483,60 @@ classicthemerestorerjso.ctr = {
 	  "extensions.classicthemerestorer.",
 	  function(branch, name) {
 		switch (name) {
+			
+		  case "tttitlebar":
+		    if(branch.getBoolPref("tttitlebar"))
+			  document.getElementById('ctraddon_pw_tttitlebar_c').disabled = false;
+			else
+			  document.getElementById('ctraddon_pw_tttitlebar_c').disabled = true;
+		  break;
 
 		  case "ctabmwidth": case "ctabwidth":
-		  
 		    if(branch.getIntPref("ctabmwidth")<48 || branch.getIntPref("ctabwidth")<48 )
 			  document.getElementById('ctraddon_pw_tabwidthinfo3').style.visibility = 'visible';
 			else
 			  document.getElementById('ctraddon_pw_tabwidthinfo3').style.visibility = 'collapse';
-		  
 		  break;
 		  
 		  case "ctabheightcb":
-		  
 		    if(branch.getBoolPref("ctabheightcb"))
 			  document.getElementById('ctraddon_pw_tabheightinfo').style.visibility = 'visible';
 			else
 			  document.getElementById('ctraddon_pw_tabheightinfo').style.visibility = 'collapse';
+		  break;
 		  
+		  case "altautocompl":
+		    if(branch.getBoolPref("altautocompl")) {
+			  document.getElementById('ctraddon_pw_cresultshcb').disabled = false;
+			  document.getElementById('ctraddon_pw_cresultsh').disabled = false;
+			} else {
+			  document.getElementById('ctraddon_pw_cresultshcb').disabled = true;
+			  document.getElementById('ctraddon_pw_cresultsh').disabled = true;
+			}
+		  break;
+		  
+		  case "ctroldsearchc":
+		    if(branch.getBoolPref("ctroldsearchc"))
+			  document.getElementById('ctraddon_pw_ctroldsearchcdelay').disabled = false;
+			else
+			  document.getElementById('ctraddon_pw_ctroldsearchcdelay').disabled = true;
+		  break;
+		  
+		  case "ctroldsearchr":
+		    if(branch.getBoolPref("ctroldsearchr"))
+			  document.getElementById('ctraddon_pw_ctroldsearchrdelay').disabled = false;
+			else
+			  document.getElementById('ctraddon_pw_ctroldsearchrdelay').disabled = true;
+		  break;
+		  
+		  case "osearch_cwidth":
+		    if(branch.getBoolPref("osearch_cwidth")) {
+			  document.getElementById('ctraddon_os_spsize_minw').disabled = false;
+			  document.getElementById('ctraddon_os_spsize_maxw').disabled = false;
+			} else {
+			  document.getElementById('ctraddon_os_spsize_minw').disabled = true;
+			  document.getElementById('ctraddon_os_spsize_maxw').disabled = true;
+			}
 		  break;
 
 		}
@@ -574,11 +591,9 @@ classicthemerestorerjso.ctr = {
 	this.ctrpwUnsortBM(this.prefs.getBoolPref("bmbunsortbm"));
 	this.ctrpwHideUrlStopRel(this.prefs.getBoolPref("hideurelstop"));
 	this.ctrpwExtraUrlbar(this.prefs.getBoolPref("extraurlkeycb"));
-	this.ctrpwSearchPopupSize(this.prefs.getBoolPref("osearch_cwidth"));
 	this.ctrpwAeroColors(this.prefs.getBoolPref("aerocolors"));
 	this.ctrpwOldTopLevelImg(this.prefs.getBoolPref("oldtoplevimg"));
 	this.ctrpwAutoCompleteHeight(this.prefs.getBoolPref("urlresults"));
-	this.ctrpwAltAutocomplete(this.prefs.getBoolPref("altautocompl"));
 	
 	var closetab_value = this.prefs.getCharPref("closetab");
   
@@ -703,11 +718,9 @@ classicthemerestorerjso.ctr = {
 	var itemvis = 'collapse';
 	
     if(which==true) {
-	  which=false;
-	  itemvis = 'visible';
+	  which=false; itemvis = 'visible';
 	} else {
-	  which=true;
-	  itemvis = 'collapse';
+	  which=true; itemvis = 'collapse';
 	}
 	
     document.getElementById('ctraddon_pw_hide_bf_popup').disabled = which;
@@ -856,16 +869,7 @@ classicthemerestorerjso.ctr = {
 	
     document.getElementById('ctraddon_extraurltarget_list').disabled = which;
   },
-  
-  ctrpwSearchPopupSize: function(which) {
-	
-    if(which==true) which=false;
-	else which=true;
-	
-	document.getElementById('ctraddon_os_spsize_minw').disabled = which;
-	document.getElementById('ctraddon_os_spsize_maxw').disabled = which;
-  },
-  
+
   ctrpwAeroColors: function(which) {
 	var itemvis = 'collapse';
 	
@@ -901,15 +905,6 @@ classicthemerestorerjso.ctr = {
 
   },
   
-  ctrpwAltAutocomplete: function(which) {
-	
-    if(which==true) which=false;
-	else which=true;
-	
-    document.getElementById('ctraddon_pw_cresultshcb').disabled = which;
-	document.getElementById('ctraddon_pw_cresultsh').disabled = which;
-  },
-
   ctrpwCtrOldSearch: function(which) {
 	
     if(which==true) which=false;
@@ -921,6 +916,10 @@ classicthemerestorerjso.ctr = {
     document.getElementById('ctraddon_pw_osearch_iwidth').disabled = which;
     document.getElementById('ctraddon_pw_osearch_meoit').disabled = which;
 	document.getElementById('ctraddon_pw_osearch_cwidth').disabled = which;
+	document.getElementById('ctraddon_pw_search_ant').disabled = which;
+	document.getElementById('ctraddon_pw_search_abl').disabled = which;
+	document.getElementById('ctraddon_pw_search_aho').disabled = which;
+	
 	if(this.prefs.getBoolPref("osearch_cwidth") && which == false) {
 	  document.getElementById('ctraddon_os_spsize_minw').disabled = false;
 	  document.getElementById('ctraddon_os_spsize_maxw').disabled = false;
@@ -928,6 +927,16 @@ classicthemerestorerjso.ctr = {
 	  document.getElementById('ctraddon_os_spsize_minw').disabled = true;
 	  document.getElementById('ctraddon_os_spsize_maxw').disabled = true;
 	}
+	if(this.prefs.getBoolPref("ctroldsearchc") && which == false) {
+	  document.getElementById('ctraddon_pw_ctroldsearchcdelay').disabled = false;
+	} else {
+	  document.getElementById('ctraddon_pw_ctroldsearchcdelay').disabled = true;
+	}
+	if(this.prefs.getBoolPref("ctroldsearchr") && which == false) {
+	  document.getElementById('ctraddon_pw_ctroldsearchrdelay').disabled = false;
+	} else {
+	  document.getElementById('ctraddon_pw_ctroldsearchrdelay').disabled = true;
+	}
 	
   },
  
@@ -1202,13 +1211,15 @@ classicthemerestorerjso.ctr = {
 	this.prefs.setBoolPref("hideurlsrg",true);
 
 	this.prefs.setBoolPref("oldsearch",true);
+
+	if(this.appversion >= 48) {
+	  this.prefs.setBoolPref("altautocompl",true);
+	  this.prefs.setBoolPref("aboutpages",true);
+	}
 	
 	if(this.appversion >= 50)
 	  this.prefs.setBoolPref("oldplacesbut",true);
-
-	if(this.appversion >= 48)
-	  this.prefs.setBoolPref("altautocompl",true);
-	
+  
 	setTimeout(function(){
 		Services.prefs.getBranch("extensions.classicthemerestorer.").setBoolPref("starinurl",true);
 		Services.prefs.getBranch("extensions.classicthemerestorer.").setBoolPref("feedinurl",true);
@@ -1232,6 +1243,9 @@ classicthemerestorerjso.ctr = {
 	this.prefs.setBoolPref("toolsitem",false);
 	this.prefs.setBoolPref("cuibuttons",false);
 	this.prefs.setBoolPref("addonversion",false);
+	this.prefs.setCharPref("altoptions",'options_default');
+	this.prefs.setBoolPref("alt_addonsm",false);
+	this.prefs.setBoolPref("am_highlight",false);
 	
 	this.needsBrowserRestart();
 
