@@ -14,6 +14,7 @@ pref("extensions.classicthemerestorer.closeonleft",false);
 pref("extensions.classicthemerestorer.closetabbig",false);
 pref("extensions.classicthemerestorer.closeicon",'closeicon_default');
 pref("extensions.classicthemerestorer.tttitlebar",false);
+pref("extensions.classicthemerestorer.tttitlebar_c",false);
 
 //Appbutton settings
 pref("extensions.classicthemerestorer.appbutton",'appbutton_v1');
@@ -39,7 +40,7 @@ pref("extensions.classicthemerestorer.hide_bf_popup",false);
 pref("extensions.classicthemerestorer.nbcompact",false);
 pref("extensions.classicthemerestorer.statusbar",true);
 pref("extensions.classicthemerestorer.noconicons",false);
-pref("extensions.classicthemerestorer.altoptions",'options_default');
+pref("extensions.classicthemerestorer.altoptions",'options_alt');
 pref("extensions.classicthemerestorer.aboutpages",false);
 pref("extensions.classicthemerestorer.svgfilters",false);
 pref("extensions.classicthemerestorer.combrelstop",false);
@@ -47,6 +48,9 @@ pref("extensions.classicthemerestorer.activndicat",false);
 pref("extensions.classicthemerestorer.nbisizedelay",0);
 pref("extensions.classicthemerestorer.findbar","findbar_default");
 pref("extensions.classicthemerestorer.findb_hide_ws",false);
+pref("extensions.classicthemerestorer.findb_widthcb",false);
+pref("extensions.classicthemerestorer.findb_widthva",170);
+pref("extensions.classicthemerestorer.nbisizedelay",0);
 pref("extensions.classicthemerestorer.nav_txt_ico","icons");
 pref("extensions.classicthemerestorer.iat_notf_vt",false);
 pref("extensions.classicthemerestorer.wincontrols",false);
@@ -62,19 +66,24 @@ pref("extensions.classicthemerestorer.alt_newtabp",false);
 pref("extensions.classicthemerestorer.nosnippets",false);
 pref("extensions.classicthemerestorer.ctroldsearch",false);
 pref("extensions.classicthemerestorer.ctroldsearchc",false);
+pref("extensions.classicthemerestorer.ctrosearchct",0);
 pref("extensions.classicthemerestorer.ctroldsearchr",false);
+pref("extensions.classicthemerestorer.ctrosearchrt",0);
 pref("extensions.classicthemerestorer.osearch_meoit",false);
+pref("extensions.classicthemerestorer.search_ant",true);
+pref("extensions.classicthemerestorer.search_abl",true);
+pref("extensions.classicthemerestorer.search_aho",true);
 pref("extensions.classicthemerestorer.osearch_dm",false);
 pref("extensions.classicthemerestorer.osearch_iwidth",true);
 pref("extensions.classicthemerestorer.osearch_cwidth",false);
 pref("extensions.classicthemerestorer.os_spsize_minw",200);
 pref("extensions.classicthemerestorer.os_spsize_maxw",200);
 pref("extensions.classicthemerestorer.addonversion",true);
-pref("extensions.classicthemerestorer.alt_addonsm",false);
+pref("extensions.classicthemerestorer.alt_addonsm",true);
 pref("extensions.classicthemerestorer.am_nowarning",false);
 pref("extensions.classicthemerestorer.am_compact",false);
 pref("extensions.classicthemerestorer.am_compact2",true);
-pref("extensions.classicthemerestorer.am_highlight",false);
+pref("extensions.classicthemerestorer.am_highlight",true);
 pref("extensions.classicthemerestorer.am_buticons",false);
 pref("extensions.classicthemerestorer.am_hovshowb",false);
 pref("extensions.classicthemerestorer.alt_addonsp",false);
@@ -140,6 +149,7 @@ pref("extensions.classicthemerestorer.autocompl_hlu",false);
 pref("extensions.classicthemerestorer.autocompl_hli",false);
 pref("extensions.classicthemerestorer.autocompl_hln",false);
 pref("extensions.classicthemerestorer.autocompl_sep",false);
+pref("extensions.classicthemerestorer.autocompl_not",false);
 pref("extensions.classicthemerestorer.autocompl_rhl",false);
 
 pref("extensions.classicthemerestorer.ib_nohovcolor",false);
@@ -235,6 +245,7 @@ pref("extensions.classicthemerestorer.contextitem",false);
 pref("extensions.classicthemerestorer.puictrbutton",false);
 pref("extensions.classicthemerestorer.cuibuttons",true);
 pref("extensions.classicthemerestorer.nodevtheme2",false);
+pref("extensions.classicthemerestorer.ctr_english",false);
 pref("extensions.classicthemerestorer.restartapp",true);
 pref("extensions.classicthemerestorer.ctrnewinv",true);
 pref("extensions.classicthemerestorer.pref_actindx",3);
